{{ self.title() }}

{{ s('background') }}

{{ s('description') }}

{{ s('input format') }}

{{ self.input_file() }}

{{ s('output format') }}

{{ self.output_file() }}

{{ s('sample', 1) }}

{{ self.sample_text() }}

{{ self.title_sample_description() }}

{{ s('sample', 2) }}

{{ self.sample_file() }}

{{ s('subtasks') }}

{{ tbl('data') }}

{{ s('scoring') }}

{{ s('hint') }}
